@@ -311,13 +311,6 @@ def write_table(
                 else None
             ).start()
         else:
-            databricks_obj = DatabricksSpark()
-            databricks_obj.set_table_all_privileges(catalog_name=db_name.split(".")[0],
-                database_name=db_name.split(".")[1],
-                spark_session=spark,
-                table_modifiers=["data-platform"],
-                table_name=table_name)
-
             stream = stream.toTable(
                 tableName=f"{db_name}.{table_name}", partitionBy=partition_columns
             )
@@ -588,6 +581,14 @@ def landing_to_bronze(
             df=df, data_pack_name=data_pack_name, dataset_name=dataset_name, layer="bronze"
         )
 
+
+    databricks_obj = DatabricksSpark()
+    databricks_obj.set_table_all_privileges(catalog_name=catalog_name,
+                    database_name=output_db_name,
+                    spark_session=spark,
+                    table_modifiers=["data-platform"],
+                    table_name=dataset_name)
+
     return True
 
 
